@@ -4,7 +4,7 @@ import sys
 
 
 configp = configparser.ConfigParser()
-config_path = "/etc/flake.ini"
+config_path = str(os.path.dirname(os.path.abspath(__file__))) + "/etc/flake.ini"
 configp.read(config_path)
 
 # check if the path is to a valid file
